\name{stacd.power}
\alias{stacd.power}
\concept{power analysis}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Power analysis for STACD model parameters
}
\description{
Performs power analysis for a single parameter in the STACD model as described in Walters et al. This power analysis is based on simulating data using the STACD model and computating of the Wald test for the parameter of interest. The power to detect the parameter is estimated by the proportion of observed significant results for the Wald test.
}
\usage{
stacd.power(betas,param,N,nrep,
        pa,pb,model="logistic",ve=NA,
        alpha=.05,plotit=TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{betas}{
a length 9 numeric vector of the STACD model parameters (in order: \emph{mu}, \emph{alpha_1}, \emph{alpha_2}, \emph{beta_1}, \emph{beta2}, \emph{gamma_ab}, \emph{gamma^*_aab}, \emph{gamma^*_abb}, and \emph{gamma^*_aabb})
}
  \item{param}{
the name of the parameter to test power for; one of c("alpha_1", "alpha_2", "beta_1", "beta_2", "gamma_ab", "gamma^*_aab", "gamma^*_abb", or "gamma^*_aabb")
}
  \item{N}{
a numeric vector of which sample sizes to use for estimating power
}
  \item{nrep}{
the number of replications to simulate
}
  \item{pa}{
allele frequency for the first locus
}
  \item{pb}{
allele frequency for the second locus
}
  \item{model}{
either "logistic" (default) or "normal" specifying which version of the STACD model to use
}
  \item{ve}{
variance of the error term for the normal model
}
  \item{alpha}{
significance level for testing power
}
  \item{plotit}{
logical, if \code{TRUE} a plot of the estimated power at each sample size will be produced
}
}
\details{
For each sample size \code{N}, data is generated according to the STACD model with the specified \code{betas}, and a Wald test is performed for the parameter of interest. This procedure is repeated for \code{nrep} replications, and the power at each sample size is estimated as the proportion of Wald tests that were observed to be significant at the given alpha level.
}
\value{
A length(N) by 2 matrix of the estimated power at each given sample size. The estimate power is the proportion of \code{nrep} replications where the Wald test for the specified parameter was significant in the generated data. If \code{plotit=TRUE}, a line plot of the power as a function of sample size is also produced.
}
\references{
Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.
}
\author{
Charles Laurin, Raymond Walters
}
\note{
Higher values of \code{nrep} will produce more accurate estimates of power, but may be slow. 

Monte Carlo power estimation with \code{stacd.power} is intended for use with the logistic STACD model. For the normal model, Monte Carlo estimation is less useful since exact power under the model can be computed.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\examples{
# Example from Walters et al.:
exvarex <- logodds.to.stacd(logodds.M=matrix(c(0,0,0, 0,0,.25, 0,0,1),3,3,byrow=TRUE),
                            pa=0.3, pb=0.3)
\dontrun{stacd.power(betas=exvarex$Betas,param="gamma^*_aab",
    N=c(1250,2500,5000,10000,15000,20000,25000,27500,30000),
    pa=.3,pb=.3,nrep=100)}

# Smaller example without plot
stacd.power(betas=exvarex$Betas,param="gamma^*_aab",
    N=c(500,1500,2500),nrep=100,pa=.3,pb=.3,plotit=FALSE)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ htest }
